
from setuptools import setup
setup(name='parakh1',
      version='0.1',
      description='add the number',
      author='parakhsg',
      author_email="parakh.tayal@sganalytics.com",
      license='MIT',
      packages=['parakh1'],
      long_description="firstpackage",
      zip_safe=False)